require 'spec_helper'
require "gill/gill"

describe Git do

  before(:all) do
    Gill.config = Settings::Config.new('/tmp')
    @uri = Parse.new('git://github.com/mephux/gill.git')
    @git = Git.new(@uri.category, @uri.folder, @uri.repo)
    @git.clone(false)
  end

  it "should parse the empty category name as false" do
    @uri.category.should == false
  end
  
  it "should parse the folder name as gill" do
    @uri.folder.should == 'gill'
  end
  
  it "should parse the repo as git://github.com/mephux/gill.git" do
    @uri.repo.should == 'git://github.com/mephux/gill.git'
  end

  it "should have a category of misc" do
    @git.category.should == 'misc'
  end
  
  it "should have a category path of /tmp/source/misc" do
    @git.category_path.should == '/tmp/source/misc'
  end
  
  it "should have a repo name of gill" do
    @git.repo_name.should == 'gill'
  end
  
  it "should have a repo path of /tmp/source/misc/gill" do
    @git.repo_path.should == '/tmp/source/misc/gill'
  end
  
  it "should create a new folder for the cloned repo" do
    File.should exist(File.join(Gill.config.default_path, @uri.folder))
  end

  it "should create a GemFile" do
    File.should exist(File.join(Gill.config.default_path, @uri.folder, 'Gemfile'))
  end

  it "should delete GIT_DIR from ENV" do
    ENV['GIT_DIR'].should be_nil
  end
  
  it "should delete GIT_INDEX_FILE from ENV" do
    ENV['GIT_INDEX_FILE'].should be_nil
  end

  it "should delete GIT_WORK_TREE from ENV" do
    ENV['GIT_WORK_TREE'].should be_nil
  end

  it "should not propegate GIT_DIR" do
    `echo $GIT_DIR`.strip.should be_empty
  end

  it "should not propegate GIT_INDEX_FILE" do
    `echo $GIT_INDEX_FILE`.strip.should be_empty
  end

  it "should not propegate GIT_WORK_TREE" do
    `echo $GIT_WORK_TREE`.strip.should be_empty
  end

end
